﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinGrid;
using System.Globalization;
using System.Diagnostics;

namespace FormatByCell
{
    #region frmMain class
    public partial class frmMain : Form
    {
        private DataTable table = null;

        public frmMain()
        {
            InitializeComponent();

            //foreach( CultureInfo ci in System.Globalization.CultureInfo.GetCultures(CultureTypes.AllCultures) )
            //{
            //    Debug.WriteLine( string.Format("{0}, {1}, {2}, {3}", ci.LCID, ci.Name, ci.EnglishName, ci.DisplayName) );
            //}

            this.grid.Dock = DockStyle.Fill;
            this.grid.InitializeLayout += new InitializeLayoutEventHandler(this.grid_InitializeLayout);
            this.grid.DataSource = this.Data;

        }


        private void grid_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            ColumnsCollection columns = e.Layout.Bands[0].Columns;
            foreach ( UltraGridColumn column in columns )
            {
                string key = column.Key;

                switch ( key )
                {
                    //  Hide the columns we don't want to user to see.
                    case "Currency":
                        column.Editor = new EditorWithText( new CustomEditorOwner() );
                        break;

                }
            }
        }

        private DataTable Data
        {
            get
            {
                if ( this.table == null )
                {
                    this.table = new DataTable();

                    //  Add columns
                    this.table.Columns.Add( "CultureName", typeof(string) );
                    this.table.Columns.Add( "CultureID", typeof(string) );
                    this.table.Columns.Add( "Currency", typeof(decimal) );

                    //  Add rows
                    this.table.Rows.Add( new object[]{ "United States", "en-US", 100d } );
                    this.table.Rows.Add( new object[]{ "Great Britain", "en-GB", 100d } );
                    this.table.Rows.Add( new object[]{ "Japan", "ja-JP", 100d } );
                    this.table.Rows.Add( new object[]{ "Russia", "ru-RU", 100d } );

                }

                return this.table;
            }
        }
    }
    #endregion frmMain class

    #region CustomEditorOwner class
    public class CustomEditorOwner : DefaultEditorOwner
    {
        public override void GetFormatInfo(object ownerContext, out string format, out IFormatProvider provider)
        {
            CellUIElement cellElement = ownerContext as CellUIElement;
            UltraGridColumn column = cellElement != null ? cellElement.Column : null;
            UltraGridRow row = cellElement != null ? cellElement.Row : null;

            if ( row != null && column != null && column.Key == "Currency" )
            {
                //  Get the value of the 'CultureID' column, which contains
                //  the name of th culture.
                UltraGridColumn cultureIDColumn = row.Band.Columns["CultureID"];
                string cellText = row.GetCellText( cultureIDColumn );
                CultureInfo culture = System.Globalization.CultureInfo.GetCultureInfo(cellText);
                
                //  Assign the culture to the 'provider' out parameter.
                provider = culture;

                //  Use the culture's NumberFormat to build a currency format that
                //  is appropriate for that culture.
                string decimalPlaces = string.Empty;
                for ( int i = 0; i < culture.NumberFormat.CurrencyDecimalDigits; i ++ )
                {
                    decimalPlaces += "0";
                }

                //  Assign the currency format to the 'format' out parameter.
                format = string.Format( "{0}#{1}{2}", culture.NumberFormat.CurrencySymbol, culture.NumberFormat.CurrencyDecimalSeparator, decimalPlaces );
            }
            else
                base.GetFormatInfo(ownerContext, out format, out provider);
        }
    }
    #endregion CustomEditorOwner class

}
